summaryrefslogtreecommitdiff
path: root/src/net/protocol.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/net/protocol.h')
-rw-r--r--src/net/protocol.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/net/protocol.h b/src/net/protocol.h
index 76610635..10c89689 100644
--- a/src/net/protocol.h
+++ b/src/net/protocol.h
@@ -191,7 +191,8 @@ enum {
ERRMSG_NO_LOGIN, // the user is not yet logged
ERRMSG_NO_CHARACTER_SELECTED, // the user needs a character
ERRMSG_INSUFFICIENT_RIGHTS, // the user is not privileged
- ERRMSG_INVALID_ARGUMENT // part of the received message was invalid
+ ERRMSG_INVALID_ARGUMENT, // part of the received message was invalid
+ ERRMSG_EMAIL_ALREADY_EXISTS // The Email Address already exists
};
// Login specific return values